<?php
/**
 * galician language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author CiberIrmandade da Fala <infoxeral@ciberirmandade.org>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Editar esta páxina';
$lang['btn_source']            = 'Amosar a fonte da páxina';
$lang['btn_show']              = 'Amosar páxina';
$lang['btn_create']            = 'Crear esta páxina';
$lang['btn_search']            = 'Procurar';
$lang['btn_save']              = 'Gardar';
$lang['btn_preview']           = 'Previsualizar';
$lang['btn_top']               = 'Comezo da páxina';
$lang['btn_newer']             = '<< máis recente';
$lang['btn_older']             = 'menos recente >>';
$lang['btn_revs']              = 'Revisións antigas';
$lang['btn_recent']            = 'Trocos recentes';
$lang['btn_upload']            = 'Subir';
$lang['btn_cancel']            = 'Cancelar';
$lang['btn_index']             = 'Índice';
$lang['btn_secedit']           = 'Editar';
$lang['btn_login']             = 'Iniciar sesión';
$lang['btn_logout']            = 'Rematar sesión';
$lang['btn_admin']             = 'Administración';
$lang['btn_update']            = 'Actualizar';
$lang['btn_delete']            = 'Borrar';
$lang['btn_back']              = 'Atrás';
$lang['btn_backlink']          = 'Ligazóns con isto';
$lang['btn_backtomedia']       = 'Volver á Selección de Arquivos-Media';
$lang['btn_subscribe']         = 'Avísame dos trocos na páxina';
$lang['btn_unsubscribe']       = 'Xa non me avises dos trocos na páxina';
$lang['btn_subscribens']       = 'Avísame dos trocos de Nomes de Espazo';
$lang['btn_unsubscribens']     = 'Xa non me avises dos trocos de Nomes de Espazo';
$lang['btn_profile']           = 'Actualizar Perfil';
$lang['btn_reset']             = 'Reiniciar';
$lang['btn_resendpwd']         = 'Envíame un novo contrasinal';
$lang['btn_draft']             = 'Editar borrador';
$lang['btn_recover']           = 'Recuperar borrador';
$lang['btn_draftdel']          = 'Eliminar borrador';
$lang['loggedinas']            = 'Iniciaches sesión coma';
$lang['user']                  = 'Nome de Usuario';
$lang['pass']                  = 'Contrasinal';
$lang['newpass']               = 'Novo Contrasinal';
$lang['oldpass']               = 'Confirmar contrasinal actual';
$lang['passchk']               = 'de novo';
$lang['remember']              = 'Lémbrame';
$lang['fullname']              = 'Nome Completo';
$lang['email']                 = 'Correo-e';
$lang['register']              = 'Rexístrate';
$lang['profile']               = 'Perfil de Usuario';
$lang['badlogin']              = 'Sentímolo, pero o nome de usuario ou o contrasinal non son correctos.';
$lang['minoredit']             = 'Trocos Menores';
$lang['draftdate']             = 'Borrador gardado automaticamente en';
$lang['nosecedit']             = 'A páxina mudou no entanto, a información da sección estaba desfasada polo que se cargou a páxina completa no seu lugar.';
$lang['regmissing']            = 'Sentímolo, pero tes que cubrir todos os campos.';
$lang['reguexists']            = 'Sentímolo, pero xa existe un usuario con ese nome.';
$lang['regsuccess']            = 'O usuario foi creado e o contrasinal enviado por correo-e.';
$lang['regsuccess2']           = 'O usuario foi creado.';
$lang['regmailfail']           = 'Semella que houbo un erro ao tentar enviar o correo-e co contrasinal. Por favor, contacto co administrador!';
$lang['regbadmail']            = 'O enderezo de correo-e proporcionado semella incorrecto - se consideras que isto é un erro, contacta co administrador';
$lang['regbadpass']            = 'Os dous contrasinais inseridos non coinciden, por favor téntao de novo.';
$lang['regpwmail']             = 'O teu contrasinal do DokuWiki';
$lang['reghere']               = 'Aínda non tes unha conta? Crea a túa';
$lang['profna']                = 'Esta wiki non permite modificacións dos perfís';
$lang['profnochange']          = 'Non hai trocos, nada que facer.';
$lang['profnoempty']           = 'Non se permite un nome ou un enderezo de correo-e baleiros.';
$lang['profchanged']           = 'Perfil de usuario actualizado correctamente.';
$lang['pwdforget']             = 'Esqueceches o teu contrasinal? Consigue un novo';
$lang['resendna']              = 'Esta wiki non permite reenvío de contrasinais.';
$lang['resendpwd']             = 'Enviar novo contrasinal a';
$lang['resendpwdmissing']      = 'Sentímolo, tes que cubrir todos os campos.';
$lang['resendpwdnouser']       = 'Sentímolo, non atopamos este usuario no noso banco de datos.';
$lang['resendpwdbadauth']      = 'Sentímolo, pero este código de autorización non é válido. Asegúrate de que usaches a ligazón completa de confirmación.';
$lang['resendpwdconfirm']      = 'Enviouse unha ligazón de confirmación por correo-e.';
$lang['resendpwdsuccess']      = 'O teu novo contrasinal foi enviado por correo-e.';
$lang['license']               = 'O contido deste wiki, agás onde se indique o contrario, ofrécese baixo da seguinte licenza:';
$lang['licenseok']             = 'Nota: Ao editares esta páxina aceptas licenciar o teu contido baixo da seguinte licenza:';
$lang['txt_upload']            = 'Selecciona o arquivo a subir';
$lang['txt_filename']          = 'Subir como (opcional)';
$lang['txt_overwrt']           = 'Sobrescribir arquivo existente';
$lang['lockedby']              = 'Bloqueado actualmente por';
$lang['lockexpire']            = 'O bloqueo remata o';
$lang['willexpire']            = 'O teu bloqueo para editar esta páxina vai rematar nun minuto.\nCo fin de evitar conflitos, usa o botón de previsualización para reiniciar o contador do tempo de bloqueo.';
$lang['notsavedyet']           = 'Perderanse os trocos non gardados.\nQueres continuar realmente?';
$lang['rssfailed']             = 'Houbo un erro ao tentar adquirir este fluxo: ';
$lang['nothingfound']          = 'Non se atopou nada.';
$lang['mediaselect']           = 'Arquivos-Media';
$lang['fileupload']            = 'Subida de Arquivos-Media';
$lang['uploadsucc']            = 'Subida correcta';
$lang['uploadfail']            = 'Fallou a subida. Pode que sexa problema de permisos?';
$lang['uploadwrong']           = 'Subida denegada. Esta extensión de arquivo non está permitida!';
$lang['uploadexist']           = 'Xa existe o arquivo. Non se fixo nada.';
$lang['uploadbadcontent']      = 'O contido subido non concorda coa extensión do arquivo %s.';
$lang['uploadspam']            = 'A subida foi bloqueada pola lista negra de spam.';
$lang['uploadxss']             = 'A subida foi bloqueada por posible contido malicioso.';
$lang['uploadsize']            = 'O arquivo subido é grande de máis. (max %s)';
$lang['deletesucc']            = 'O arquivo "%s" foi eliminado.';
$lang['deletefail']            = '"%s" non puido ser eliminado - comproba os permisos.';
$lang['mediainuse']            = 'O arquivo "%s" non foi eliminado - aínda está en uso.';
$lang['namespaces']            = 'Nomes de espazos';
$lang['mediafiles']            = 'Arquivos dispoñibles en';
$lang['js']['keepopen']        = 'Manter a xanela aberta na selección';
$lang['js']['hidedetails']     = 'Agochar Pormenores';
$lang['js']['nosmblinks']      = 'A ligazón aos compartidos do Windows só funciona no Microsoft Internet Explorer.
Sempre podes copiar e colar a ligazón.';
$lang['js']['mu_btn']          = 'Subir varios arquivos dunha vez';
$lang['mediausage']            = 'Utilizar a seguinte sintaxe para referenciar este arquivo:';
$lang['mediaview']             = 'Ver arquivo orixinal';
$lang['mediaroot']             = 'raigaña';
$lang['mediaupload']           = 'Sube un arquivo ao nome de espazo actual aquí. Para crear sub-nomes de espazos deberás antepoñelos ao nome indicado en "Subir como" separados por dous puntos.';
$lang['mediaextchange']        = 'Extensión de arquivo mudada de .%s a .%s!';
$lang['reference']             = 'Referencias para';
$lang['ref_inuse']             = 'o arquivo non pode ser eliminado, xa que aínda está a ser usado polas seguintes páxinas:';
$lang['ref_hidden']            = 'Algunhas referencias están en páxinas para as cales non tes permisos de lectura';
$lang['hits']                  = 'Vistas';
$lang['quickhits']             = 'Nomes de páxinas coincidentes';
$lang['toc']                   = 'Táboa de Contidos';
$lang['current']               = 'actual';
$lang['yours']                 = 'A túa Versión';
$lang['diff']                  = 'amosar diferenzas coa versión actual';
$lang['diff2']                 = 'Amosar diferenzas entre as revisións seleccionadas';
$lang['line']                  = 'Liña';
$lang['breadcrumb']            = 'Trazado';
$lang['youarehere']            = 'Estás aquí';
$lang['lastmod']               = 'Última modificación';
$lang['by']                    = 'por';
$lang['deleted']               = 'eliminado';
$lang['created']               = 'creado';
$lang['restored']              = 'revisión antiga restaurada';
$lang['external_edit']         = 'edición externa';
$lang['summary']               = 'Resumo da edición';
$lang['noflash']               = 'Precísase o <a href="http://www.adobe.com/products/flashplayer/">Complemento Adobe Flash</a> para amosar este contido.';
$lang['mail_newpage']          = 'páxina engadida:';
$lang['mail_changed']          = 'páxina mudada:';
$lang['mail_new_user']         = 'Novo usuario:';
$lang['mail_upload']           = 'arquivo subido:';
$lang['qb_alert']              = 'Por favor, insire o texto que queres formatear.\nSerá engadido ao remate do documento.';
$lang['qb_bold']               = 'Texto Resaltado';
$lang['qb_italic']             = 'Texto en Cursiva';
$lang['qb_underl']             = 'Texto Subliñado';
$lang['qb_code']               = 'Texto de Código';
$lang['qb_strike']             = 'Texto Riscado';
$lang['qb_h1']                 = 'Liña de Cabeceira de Nivel 1';
$lang['qb_h2']                 = 'Liña de Cabeceira de Nivel 2';
$lang['qb_h3']                 = 'Liña de Cabeceira de Nivel 3';
$lang['qb_h4']                 = 'Liña de Cabeceira de Nivel 4';
$lang['qb_h5']                 = 'Liña de Cabeceira de Nivel 5';
$lang['qb_link']               = 'Ligazón Interna';
$lang['qb_extlink']            = 'Ligazón Externa';
$lang['qb_hr']                 = 'Liña Horizontal';
$lang['qb_ol']                 = 'Elemento de Lista Ordenada';
$lang['qb_ul']                 = 'Elemento de Lista Desordenada';
$lang['qb_media']              = 'Engadir Imaxes e outros arquivos';
$lang['qb_sig']                = 'Inserir Sinatura';
$lang['qb_smileys']            = 'Risoños';
$lang['qb_chars']              = 'Caracteres Especiais';
$lang['del_confirm']           = 'Eliminar o(s) elemento(s) seleccionado(s) realmente?';
$lang['admin_register']        = 'Engadir novo usuario';
$lang['metaedit']              = 'Editar Metadatos';
$lang['metasaveerr']           = 'Non se puideron escribir os metadatos';
$lang['metasaveok']            = 'Metadatos gardados';
$lang['img_backto']            = 'Volver a';
$lang['img_title']             = 'Título';
$lang['img_caption']           = 'Lenda';
$lang['img_date']              = 'Data';
$lang['img_fname']             = 'Nome de arquivo';
$lang['img_fsize']             = 'Tamaño';
$lang['img_artist']            = 'Fotógrafo';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Formato';
$lang['img_camera']            = 'Cámara';
$lang['img_keywords']          = 'Chaves';
$lang['subscribe_success']     = 'Engadiuse %s á lista de subscrición dos trocos de %s';
$lang['subscribe_error']       = 'Erro ao tentar engadir %s á lista de subscrición dos trocos de %s';
$lang['subscribe_noaddress']   = 'Non hai enderezo ningún asociado co teu usuario, non podes ser engadido á lista de subscrición';
$lang['unsubscribe_success']   = 'Eliminouse %s da lista de subscrición dos trocos de %s';
$lang['unsubscribe_error']     = 'Erro ao tentar eliminar %s da lista de subscrición dos trocos de %s';
$lang['authmodfailed']         = 'Configuración de autenticación de usuario incorrecta. Por favor, informa ao Administrador do teu Wiki.';
$lang['authtempfail']          = 'A autenticación de usuario non está dispoñible de xeito temporal. Se esta situación persiste, por favor, informa ao Administrador do teu Wiki.';
$lang['i_chooselang']          = 'Escolle o teu idioma';
$lang['i_installer']           = 'Instalador do DokuWiki';
$lang['i_wikiname']            = 'Nome do Wiki';
$lang['i_enableacl']           = 'Activar ACL (recomendado)';
$lang['i_superuser']           = 'Super-usuario';
$lang['i_problems']            = 'O instalador atopou algúns problemas amosados de seguido. Non poderás continuar ata que os soluciones.';
$lang['i_modified']            = 'Por razóns de seguridade este script só funcionará cunha instalación nova e sen modificar do Dokuwiki.
                         Podes ou ben re-extraer os arquivos dende o paquete descargado ou consultar as
                         <a href="http://dokuwiki.org/install">instruccións completas de instalación do Dokuwiki</a>';
$lang['i_funcna']              = 'A función <code>%s</code> do PHP non está dispoñible. Pode que o teu provedor de hospedaxe a desactivase por algún motivo?';
$lang['i_phpver']              = 'A túa versión <code>%s</code> do PHP é inferior á <code>%s</code> precisa. Debes actualizar a túa instalación do PHP.';
$lang['i_permfail']            = '<code>%s</code> non é escribible polo DokuWiki. Debes corrixir a configuración de permisos deste directorio!';
$lang['i_confexists']          = '<code>%s</code> xa existe';
$lang['i_writeerr']            = 'Non se puido crear <code>%s</code>. Terás que comprobar os permisos do directorio/arquivo e crear o ficheiro de xeito manual.';
$lang['i_badhash']             = 'dokuwiki.php irrecoñecible ou modificado (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - ilegal ou valor baleiro';
$lang['i_success']             = 'A configuración rematou correctamente. Agora podes borrar o arquivo install.php. Continúa deica o
                        <a href="doku.php">teu novo DokuWiki</a>.';
$lang['i_failure']             = 'Houbo algúns erros ao tentar escribir os arquivos de configuración. Pode que precises solucionalos de xeito manual antes
                         de que poidas usar <a href="doku.php">o teu novo DokuWiki</a>.';
$lang['i_policy']              = 'Regras iniciais do ACL';
$lang['i_pol0']                = 'Wiki Aberto (lectura, escritura, subida de arquivos para todo o mundo)';
$lang['i_pol1']                = 'Wiki Público (lectura para todo o mundo, escritura e subida de arquivos para usuarios rexistrados)';
$lang['i_pol2']                = 'Wiki Pechado (lectura, escritura, subida de arquivos só para usuarios rexistrados)';
$lang['i_retry']               = 'Probar de novo';
$lang['mu_intro']              = 'Aquí podes subir varios arquivos dunha vez. Preme o botón navegar para engadilos á cola. Preme subir cando remates.';
$lang['mu_gridname']           = 'Nome de arquivo';
$lang['mu_gridsize']           = 'Tamaño';
$lang['mu_gridstat']           = 'Estado';
$lang['mu_namespace']          = 'Nome de espazo';
$lang['mu_browse']             = 'Navegar';
$lang['mu_toobig']             = 'demasiado grande';
$lang['mu_ready']              = 'listo para subir';
$lang['mu_done']               = 'completo';
$lang['mu_fail']               = 'fallou';
$lang['mu_authfail']           = 'sesión expirada';
$lang['mu_progress']           = '@PCT@% subido';
$lang['mu_filetypes']          = 'Tipos de arquivo Permitidos';
$lang['recent_global']         = 'Agora mesmo estás a ver os trocos no nome de espazo <b>%s</b>. Tamén podes <a href="%s">ver os trocos recentes no wiki enteiro</a>.';
